@@ -150,6 +150,13 @@ RadialMap::Widget::paintExplodedLabels(QPainter &paint) const
     //**** should perhaps use doubles
     int  *sizes = new int [ m_map.m_visibleDepth + 1 ]; //**** make sizes an array of floats I think instead (or doubles)
 
+    // If the minimum is larger than the default it fucks up further down
+    if (paint.font().pointSize() < Config::minFontPitch) {
+        QFont font = paint.font();
+        font.setPointSize(Config::minFontPitch);
+        paint.setFont(font);
+    }
+    
     QList<Label*>::iterator it;
 
     do
